#
# spec file for package python-poetry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-poetry%{psuffix}
Version:        1.8.3
Release:        1.1
Summary:        Python dependency management and packaging
License:        MIT
Group:          Development/Languages/Python
URL:            https://python-poetry.org/
# PyPI sdist doesn't contain tests
Source:         https://github.com/python-poetry/poetry/archive/%{version}.tar.gz#/poetry-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.7.0 with %python-poetry-core < 2.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-build >= 1.0.3
Requires:       python-poetry-core = 1.9.0
Requires:       python-poetry-plugin-export >= 1.6.0
# SECTION cachecontrol[filecache]
Requires:       python-CacheControl >= 0.13
Requires:       python-filelock >= 3.8.0
# /SECTION
Requires:       python-cleo >= 2.0.0
Requires:       python-crashtest >= 0.4.1
Requires:       python-dulwich >= 0.21.2
Requires:       python-fastjsonschema >= 2.18.0
%if 0%{?python_version_nodots} < 310
Requires:       python-importlib-metadata >= 4.4
%endif
Requires:       python-installer >= 0.7.0
Requires:       python-keyring >= 24.0
Requires:       python-packaging >= 23.1
Requires:       python-pexpect >= 4.7.0
Requires:       python-pkginfo >= 1.10.0
Requires:       python-pyproject-hooks >= 1.0.0
Requires:       python-requests >= 2.26
Requires:       python-shellingham >= 1.5
Requires:       (python-platformdirs >= 3.0.0 with python-platformdirs < 5)
Requires:       (python-requests-toolbelt >= 1.0.0 with python-requests-toolbelt < 2)
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli >= 2.0.1
%endif
Requires:       python-trove-classifiers >= 2022.5.19
Requires:       python-virtualenv >= 20.22
Requires:       (python-tomlkit >= 0.11.4 with python-tomlkit < 1.0)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     git-core
Recommends:     python-devel
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module cachy >= 0.3.0}
BuildRequires:  %{python_module deepdiff >= 6.3}
BuildRequires:  %{python_module httpretty >= 1.0}
# Required because deepdiff > 6.2.3
BuildRequires:  %{python_module orjson}
BuildRequires:  %{python_module poetry = %{version}}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest >= 7.1}
BuildRequires:  %{python_module pytest-mock >= 3.9}
BuildRequires:  %{python_module pytest-xdist >= 3.1}
BuildRequires:  git-core
%endif
%python_subpackages

%description
Python dependency management and packaging made easy.

%prep
%autosetup -p1 -n poetry-%{version}
for f in console/events/console_events.py \
         layouts/standard.py; do
  [ -e src/poetry/$f ] || exit 1 # file does not exist
  [ ! -s src/poetry/$f ] && echo "# empty module" >> src/poetry/$f || exit 2 # file is not empty
done

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/poetry
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# can't install setuptools from PyPI (no network)
donttest="test_uninstall_git_package_nspkg_pth_cleanup or test_builder_setup_generation_runs_with_pip_editable"
donttest="$donttest or test_installer_with_pypi_repository"
# does not find the expected packages in venv
donttest="$donttest or test_executor_should_write_pep610_url_references"
donttest="$donttest or test_prepare_directory or test_prepare_sdist"
donttest="$donttest or test_isolated_env_install_success"
# different hashes in our own ecosystem
donttest="$donttest or test_executor_known_hashes"
# no command "exit-code"
donttest="$donttest or test_info_setup_complex_calls_script"
%{python_expand # pytest needs to be called from the virtualenv python interpreter gh#python-poetry/poetry#1645
virtualenv-%{$python_bin_suffix} --system-site-packages testenv-%{$python_bin_suffix}
source testenv-%{$python_bin_suffix}/bin/activate
export PYTHONDONTWRITEBYTECODE=1
python -m pytest -v -k "not ($donttest)"
deactivate
}
%endif

%post
%python_install_alternative poetry

%postun
%python_uninstall_alternative poetry

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/poetry
%{python_sitelib}/poetry-%{version}.dist-info
%python_alternative %{_bindir}/poetry
%endif

%changelog
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.3:
  * Add support for untagged CPython builds with versions ending
    with a `+` (#9207).
  * Require `pkginfo>=1.10` to ensure support for packages with
    metadata version 2.3 (#9130).
  * Improve locking on FIPS systems (#9152).
  * Fix an issue where unrecognized package metadata versions
    silently resulted in empty dependencies (#9203,
  * #9226).
  * Fix an issue where trailing slashes in git URLs where not
    handled correctly (#9205).
  * Fix an issue where `poetry self` commands printed a warning
    that the current project cannot be installed (#9302).
  * Fix an issue where `poetry install` sporadically failed with
    a `KeyError` due to a race condition (#9335).
  * Fix incorrect information about `poetry shell` (#9060).
  * Add a git subdirectory example to `poetry add` (#9080).
  * Mention interactive credential configuration (#9074).
  * Add notes for optional advanced installation steps (#9098).
  * Add reference to configuration credentials in documentation
    of poetry `publish` (#9110).
  * Improve documentation for configuring credentials via
    environment variables (#9121).
  * Remove misleading wording around virtual environments
    (#9213).
  * Remove outdated advice regarding seeding keyring backends
    (#9213).
  * Add a `pyproject.toml` example for a dependency with multiple
    extras (#9138).
  * Clarify help of `poetry add` (#9230).
  * Add a note how to configure credentials for TestPyPI for
    `poetry publish` (#9255).
  * Fix information about the `--readme` option in `poetry new`
    (#9260).
  * Clarify what is special about the Python constraint in
    `dependencies` (#9256).
  * Update how to uninstall plugins via `pipx` (#9320).
* Tue Mar 19 2024 Ben Greiner <code@bnavigator.de>
- Update to version 1.8.2
  * Harden lazy-wheel error handling if the index server is
    behaving badly in an unexpected way (#9051).
  * Improve lazy-wheel error handling if the index server does not
    handle HTTP range requests correctly (#9082).
  * Improve lazy-wheel error handling if the index server pretends
    to support HTTP range requests but does not respect them
    (#9084).
  * Improve lazy-wheel to allow redirects for HEAD requests
    (#9087).
  * Improve debug logging for lazy-wheel errors (#9059).
  * Fix an issue where the hash of a metadata file could not be
    calculated correctly due to an encoding issue (#9048).
  * Fix an issue where poetry add failed in non-package mode if no
    project name was set (#9046).
  * Fix an issue where a hint to non-package mode was not compliant
    with the final name of the setting (#9073).
- Release 1.8.1
  * Update the minimum required version of packaging (#9031).
  * Handle unexpected responses from servers that do not support
    HTTP range requests with negative offsets more robust (#9030).
- Release 1.8.0
  [#]# Added
  * Add a non-package mode for use cases where Poetry is only used
    for dependency management (#8650).
  * Add support for PEP 658 to fetch metadata without having to
    download wheels (#5509).
  * Add a lazy-wheel config option (default: true) to reduce wheel
    downloads during dependency resolution (#8815, #8941).
  * Improve performance of dependency resolution by using shallow
    copies instead of deep copies (#8671).
  * poetry check validates that no unknown sources are referenced
    in dependencies (#8709).
  * Add archive validation during installation for further hash
    algorithms (#8851).
  * Add a to key in tool.poetry.packages to allow custom subpackage
    names (#8791).
  * Add a config option to disable keyring (#8910).
  * Add a --sync option to poetry update (#8931).
  * Add an --output option to poetry build (#8828).
  * Add a --dist-dir option to poetry publish (#8828).
  [#]# Changed
  * The implicit PyPI source is disabled if at least one primary
    source is configured (#8771).
  * Deprecate source priority default (#8771).
  * Upgrade the warning about an inconsistent lockfile to an error
    (#8737).
  * Deprecate setting installer.modern-installation to false
    (#8988).
  * Drop support for pip<19 (#8894).
  * Require requests-toolbelt>=1 (#8680).
  * Allow platformdirs 4.x (#8668).
  * Allow and require xattr 1.x on macOS (#8801).
  * Improve venv shell activation in fish (#8804).
  * Rename system to base in output of poetry env info (#8832).
  * Use pretty name in output of poetry version (#8849).
  * Improve error handling for invalid entries in
    tool.poetry.scripts (#8898).
  * Improve verbose output for dependencies with extras during
    dependency resolution (#8834).
  * Improve message about an outdated lockfile (#8962).
  [#]# Fixed
  * Fix an issue where poetry shell failed when Python has been
    installed with MSYS2 (#8644).
  * Fix an issue where Poetry commands failed in a terminal with a
    non-UTF-8 encoding (#8608).
  * Fix an issue where a missing project name caused an
    incomprehensible error message (#8691).
  * Fix an issue where Poetry failed to install an sdist path
    dependency (#8682).
  * Fix an issue where poetry install failed because an unused
    extra was not available (#8548).
  * Fix an issue where poetry install --sync did not remove an
    unrequested extra (#8621).
  * Fix an issue where poetry init did not allow specific
    characters in the author field (#8779).
  * Fix an issue where Poetry could not download sdists from
    misconfigured servers (#8701).
  * Fix an issue where metadata of sdists that call CLI tools of
    their build requirements could not be determined (#8827).
  * Fix an issue where Poetry failed to use the currently activated
    environment (#8831).
  * Fix an issue where poetry shell failed in zsh if a space was in
    the venv path (#7245).
  * Fix an issue where scripts with extras could not be installed
    (#8900).
  * Fix an issue where explicit sources where not propagated
    correctly (#8835).
  * Fix an issue where debug prints where swallowed when using a
    build script (#8760).
  * Fix an issue where explicit sources of locked dependencies
    where not propagated correctly (#8948).
  * Fix an issue where Poetry's own environment was falsely
    identified as system environment (#8970).
  * Fix an issue where dependencies from a setup.py were ignored
    silently (#9000).
  * Fix an issue where environment variables for virtualenv.options
    were ignored (#9015).
  * Fix an issue where virtualenvs.options.no-pip and
    virtualenvs.options.no-setuptools were not normalized (#9015).
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Fix an issue where sdists that call CLI tools of their build
    requirements could not be installed (#8630).
  * Fix an issue where sdists with symlinks could not be
    installed due to a broken tarfile datafilter (#8649).
  * Fix an issue where `poetry init` failed when trying to add
    dependencies (#8655).
  * Fix an issue where `poetry install` failed if
    `virtualenvs.create` was set to `false` (#8672).
  * Add official support for Python 3.12 (#7803, #8544).
  * Add `poetry-install` pre-commit hook (#8327).
  * Add `--next-phase` option to `poetry version` (#8089).
  * Print a warning when overwriting files from another package
    at installation (#8386).
  * Print a warning if the current project cannot be installed
    (#8369).
  * Report more details on build backend exceptions (#8464).
  * Set Poetry as `user-agent` for all HTTP requests (#8394).
  * Do not install `setuptools` per default in Python 3.12
  * Do not install `wheel` per default (#7803).
  * Remove `setuptools` and `wheel` when running `poetry install
  - -sync` if they are not required by the project (#8600).
  * Improve error message about PEP-517 support (#8463).
  * Improve `keyring` handling (#8227).
  * Read the `description` field when extracting metadata from
    `setup.py` files (#8545).
  * Fix an issue where dependencies of inactive extras were
    locked and installed (#8399).
  * Fix an issue where build requirements were not installed
    due to a race condition in the artifact cache (#8517).
  * Fix an issue where packages included in the system site
    packages were installed even though
    `virtualenvs.options.system-site-packages` was set (#8359).
  * Fix an issue where git dependencies' submodules with relative
    URLs were handled incorrectly (#8020).
  * Fix an issue where a failed installation of build
    dependencies was not noticed directly (#8479).
  * Fix an issue where `poetry shell` did not work completely
    with `nushell` (#8478).
  * Fix an issue where a confusing error messages was displayed
    when running `poetry config pypi-token.pypi` without a value
    (#8502).
  * Fix an issue where a cryptic error message is printed if
    there is no metadata entry in the lockfile (#8523).
  * Fix an issue with the encoding with special characters in the
    virtualenv's path (#8565).
  * Fix an issue where the connection pool size was not adjusted
    to the number of workers (#8559).
  * ### Docs
  * Improve the wording regarding a project's supported Python
    range (#8423).
  * Make `pipx` the preferred (first mentioned) installation
    method (#8090).
  * Add a warning about `poetry self` on Windows (#8090).
  * Fix example for `poetry add` with a git dependency (#8438).
  * Add information about auto-included files in wheels and sdist
    (#8555).
  * Fix documentation of the `POETRY_REPOSITORIES_` variables
    docs (#8492).
  * Add `CITATION.cff` file (#8510).
  * ### poetry-core (`1.8.1`)
  * Add support for creating packages dynamically in the build
    script (#629).
  * Improve marker logic for `extra` markers (#636).
  * Update list of supported licenses (#635, #646).
  * Fix an issue where projects with extension modules were not
    installed in editable mode (#633).
  * Fix an issue where the wrong or no `lib` folder was added to
    the wheel (#634).
  * ### poetry-plugin-export (`^1.6.0`)
  * Add an `--all-extras` option (#241).
  * Fix an issue where git dependencies are exported with the
    branch name instead of the resolved commit hash (#213).
-  drop build-1.patch, poetry-pr8447-fastjsonschema.patch
  (upstream)
* Thu Sep 28 2023 Ben Greiner <code@bnavigator.de>
- Drop unlimit-jsonschema.patch in favor of
  poetry-pr8447-fastjsonschema.patch
  * gh#python-poetry/poetry#8447
* Thu Sep 28 2023 Dirk Müller <dmueller@suse.com>
- add unlimit-jsonschema.patch to avoid installation issue
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Fix dependencies
* Thu Sep 21 2023 Ondřej Súkup <mimi.vx@gmail.com>
- add build-1.patch to fix compatibility with python-build-1.0+
- update to 1.6.1
  * Add support for repositories that do not provide a supported
    hash algorithm
  * Add full support for duplicate dependencies with overlapping
    markers
  * Improve performance of poetry lock for certain edge cases
  * Improve performance of poetry install
  * poetry check validates that specified readme files do exist
  * Add a downgrading note when updating to an older version
  * Add support for vox in the xonsh shell
  * Add support for pre-commit hooks for projects where the
    pyproject.toml file is located in a subfolder
  * Add support for the git+http:// scheme
  * Drop support for Python 3.7
  * Move poetry lock --check to poetry check --lock and
    deprecate the former
  * Change future warning that PyPI will only be disabled
    automatically if there are no primary sources
  * Update the minimum required version of requests
  * Fix an issue where build-system.requires were not respected
    for projects with build scripts
  * Fix an issue where the encoding was not handled correctly
    when calling a subprocess
  * Fix an issue where poetry show --top-level did not show top
    level dependencies with extras
  * Fix an issue where poetry init handled projects with src
    layout incorrectly
  * Fix an issue where Poetry wrote .pth files with the wrong
    encoding
  * Fix an issue where poetry install did not respect the source
    if the same version of a package has been locked from
    different sources
  * Document official Poetry badge
  * Add a warning about pip ignoring lock files
  * Clarify the use of the virtualenvs.in-project setting.
  * Fix command for listing installed plugins
  * Mention the nox-poetry package
  * Add an example with a PyPI source in the pyproject.toml file
  * Use reference instead of deprecated callable in the scripts example
* Mon May 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.5.1
  [#]# Added
  * Improve dependency resolution performance in cases with a lot
    of backtracking (#7950).
  [#]# Changed
  * Disable wheel content validation during installation (#7987).
  [#]# Fixed
  * Fix an issue where partially downloaded wheels were cached
    (#7968).
  * Fix an issue where poetry run did no longer execute
    relative-path scripts (#7963).
  * Fix an issue where dependencies were not installed in
    in-project environments (#7977).
  * Fix an issue where no solution was found for a transitive
    dependency on a pre-release of a package (#7978).
  * Fix an issue where cached repository packages were incorrectly
    parsed, leading to its dependencies being ignored (#7995).
  * Fix an issue where an explicit source was ignored so that a
    direct origin dependency was used instead (#7973).
  * Fix an issue where the installation of big wheels consumed a
    lot of memory (#7987).
* Mon May 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.5.0
  [#]# Added
  * Introduce the new source priorities explicit and supplemental
    (#7658, #6879).
  * Introduce the option to configure the priority of the implicit
    PyPI source (#7801).
  * Add handling for corrupt cache files (#7453).
  * Improve caching of URL and git dependencies (#7693, #7473).
  * Add option to skip installing directory dependencies (#6845,
    [#7923]).
  * Add --executable option to poetry env info (#7547).
  * Add --top-level option to poetry show (#7415).
  * Add --lock option to poetry remove (#7917).
  * Add experimental POETRY_REQUESTS_TIMEOUT option (#7081).
  * Improve performance of wheel inspection by avoiding unnecessary
    file copy operations (#7916).
  [#]# Changed
  * Remove the old deprecated installer and the corresponding
    setting experimental.new-installer (#7356).
  * Introduce priority key for sources and deprecate flags default
    and secondary (#7658).
  * Deprecate poetry run <entry point> if the entry point was not
    previously installed via poetry install (#7606).
  * Only write the lock file if the installation succeeds (#7498).
  * Do not write the unused package category into the lock file
    (#7637).
  [#]# Fixed
  * Fix an issue where Poetry's internal pyproject.toml continually
    grows larger with empty lines (#7705).
  * Fix an issue where Poetry crashes due to corrupt cache files
    (#7453).
  * Fix an issue where the Retry-After in HTTP responses was not
    respected and retries were handled inconsistently (#7072).
  * Fix an issue where Poetry silently ignored invalid groups
    (#7529).
  * Fix an issue where Poetry does not find a compatible Python
    version if not given explicitly (#7771).
  * Fix an issue where the direct_url.json of an editable install
    from a git dependency was invalid (#7473).
  * Fix an issue where error messages from build backends were not
    decoded correctly (#7781).
  * Fix an infinite loop when adding certain dependencies (#7405).
  * Fix an issue where pre-commit hooks skip pyproject.toml files
    in subdirectories (#7239).
  * Fix an issue where pre-commit hooks do not use the expected
    Python version (#6989).
  * Fix an issue where an unclear error message is printed if the
    project name is the same as one of its dependencies (#7757).
  * Fix an issue where poetry install returns a zero exit status
    even though the build script failed (#7812).
  * Fix an issue where an existing .venv was not used if in-project
    was not set (#7792).
  * Fix an issue where multiple extras passed to poetry add were
    not parsed correctly (#7836).
  * Fix an issue where poetry shell did not send a newline to fish
    (#7884).
  * Fix an issue where poetry update --lock printed operations that
    were not executed (#7915).
  * Fix an issue where poetry add --lock did perform a full update
    of all dependencies (#7920).
  * Fix an issue where poetry shell did not work with nushell
    (#7919).
  * Fix an issue where subprocess calls failed on Python 3.7
    (#7932).
  * Fix an issue where keyring was called even though the password
    was stored in an environment variable (#7928).
- Drop poetry-pr7893-unpin-requests-toolbelt.patch
* Mon May  8 2023 Ben Greiner <code@bnavigator.de>
- Sync requests-toolbelt clamps with python metadata
  * Add poetry-pr7893-unpin-requests-toolbelt.patch
  * gh#python-poetry/poetry#7893
* Mon May  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-requests-toolbelt upper version limit to make it work
  with latest request (1.0.0)
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue May  2 2023 Ben Greiner <code@bnavigator.de>
- Skip suddenly failing test not finding setuptools (due to
  virtualenv update to v20.22)
* Mon Apr 24 2023 Torsten Gruner <simmphonie@opensuse.org>
- Update to 1.4.2
  * When trying to install wheels with invalid RECORD files, Poetry does
    not fail anymore but only prints a warning.
    This mitigates an unintended change introduced in Poetry 1.4.1 (#7694).
  * Fix an issue where relative git submodule urls were not parsed correctly (#7017).
  * Fix an issue where Poetry could freeze when building a project with a build
    script if it generated enough output to fill the OS pipe buffer (#7699).
- Changes in 1.4.0
  * Add a modern installer (installer.modern-installation) for
    faster installation of packages and independence from pip
    (#6205).
  * Add support for Private :: trove classifiers (#7271).
  * Add the version of poetry in the @generated comment at the
    beginning of the lock file (#7339).
  * Add support for virtualenvs.prefer-active-python when running
    poetry new and poetry init (#7100).
  * Deprecate the old installer, i.e. setting
    experimental.new-installer to false (#7358).
  * Remove unused platform field from cached package info and bump
    the cache version (#7304).
  * Extra dependencies of the root project are now sorted in the
    lock file (#7375).
  * Remove upper boundary for importlib-metadata dependency
    (#7434).
  * Validate path dependencies during use instead of during
    construction (#6844).
  * Remove the deprecated repository modules (#7468).
* Fri Feb 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-orjson test requirement, it's needed because
  python-deepdiff > 6.2.3.
  gh#python-poetry/poetry@68770a67ef7e#diff-50c86b7ed8ac2cf95bd48334961bf0530cdc77b5a56f852c5c61b89d735fd711R93
* Sun Jan 15 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.3.2
  * Fix a performance regression when locking dependencies from
    PyPI (#7232).
  * Fix an issue where passing a relative path via -C, --directory
    fails (#7266).
- Fix multibuild test src.rpm package names
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Fix python-tomli requirement, there's no release > 2.0.1 yet.
* Tue Dec 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.3.1
  * Fix an issue where an explicit dependency on lockfile was
    missing, resulting in a broken Poetry in rare circumstances
    (7169).
- Catch up with upstream dependencies changed in previous updates
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.3.0
  Added
  * Mark the lock file with an @generated comment as used by common tooling (#2773).
  * poetry check validates trove classifiers and warns for deprecations (#2881).
  * Introduce a top level -C, --directory option to set the working path (#6810).
  Changed
  * New lock file format (version 2.0) (#6393).
  * Path dependency metadata is unconditionally re-locked (#6843).
  * URL dependency hashes are locked (#7121).
  * poetry update and poetry lock should now resolve dependencies more similarly (#6477).
  * poetry publish will report more useful errors when a file does not exist (#4417).
  * poetry add will check for duplicate entries using canonical names (#6832).
  * Wheels are preferred to source distributions when gathering metadata (#6547).
  * Git dependencies of extras are only fetched if the extra is requested (#6615).
  * Invoke pip with --no-input to prevent hanging without feedback (#6724, #6966).
  * Invoke pip with --isolated to prevent the influence of user configuration (#6531).
  * Interrogate environments with Python in isolated (-I) mode (#6628).
  * Raise an informative error when multiple version constraints overlap and are incompatible (#7098).
  Fixed
  * Fix an issue where concurrent instances of Poetry would corrupt the artifact cache (#6186).
  * Fix an issue where Poetry can hang after being interrupted due to stale locking in cache (#6471).
  * Fix an issue where the output of commands executed with --dry-run contained duplicate entries (#4660).
  * Fix an issue where requests’s pool size did not match the number of installer workers (#6805).
  * Fix an issue where poetry show --outdated failed with a runtime error related to direct origin dependencies (#6016).
  * Fix an issue where only the last command of an ApplicationPlugin is registered (#6304).
  * Fix an issue where git dependencies were fetched unnecessarily when running poetry lock --no-update (#6131).
  * Fix an issue where stdout was polluted with messages that should go to stderr (#6429).
  * Fix an issue with poetry shell activation and zsh (#5795).
  * Fix an issue where a url dependencies were shown as outdated (#6396).
  * Fix an issue where the source field of a dependency with extras was ignored (#6472).
  * Fix an issue where a package from the wrong source was installed for a multiple-constraints dependency with different sources (#6747).
  * Fix an issue where dependencies from different sources where merged during dependency resolution (#6679).
  * Fix an issue where experimental.system-git-client could not be used via environment variable (#6783).
  * Fix an issue where Poetry fails with an AssertionError due to distribution.files being None (#6788).
  * Fix an issue where poetry env info did not respect virtualenvs.prefer-active-python (#6986).
  * Fix an issue where poetry env list does not list the in-project environment (#6979).
  * Fix an issue where poetry env remove removed the wrong environment (#6195).
  * Fix an issue where the return code of a script was not relayed as exit code (#6824).
  * Fix an issue where the solver could silently swallow ValueError (#6790).
  Docs
  * Improve documentation of package sources (#5605).
  * Correct the default cache path on Windows (#7012).
* Mon Oct 10 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.2.2
  * Add forward compatibility for lock file format 2.0, which will
    be used by Poetry 1.3 (#6608).
  * Allow poetry lock to re-generate the lock file when invalid or
    incompatible (#6753).
  * Fix an issue where the deprecated JSON API was used to query
    PyPI for available versions of a package (#6081).
  * Fix an issue where versions were escaped wrongly when building
    the wheel name (#6476).
  * Fix an issue where the installation of dependencies failed if
    pip is a dependency and is updated in parallel to other
    dependencies (#6582).
  * Fix an issue where the names of extras were not normalized
    according to PEP 685 (#6541).
  * Fix an issue where sdist names were not normalized (#6621).
  * Fix an issue where invalid constraints, which are ignored, were
    only reported in a debug message instead of a warning (#6730).
* Sun Oct  9 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.2.1
  * Bump poetry-core to 1.2.0.
  * Bump poetry-plugin-export to ^1.0.7.
- Release 1.2.0
  * https://python-poetry.org/blog/announcing-poetry-1.2.0/
  * Dropping support for Python 2.7, 3.5 and 3.6 as runtimes
  * Dependency groups
  * Plugin support
  * Migration of the poetry export command
  * Support for yanked releases (PEP 592)
  * Support for Direct Origin URL records (PEP 610)
  * Subdirectory support for Git dependencies
  * Single page repository support
  * Synchronizing the environment with the lock file
  * Opting out of binary distributions
  * Native Python git client
  * Detection of the currently active Python (experimental)
  * PEP 508 dependency specification parsing
  * Comprehensive HTTPS certificate support
  * Non-verbose error handling
  * Management of setuptools and pip
  * Keyring backend issues
  * Usefulness of experimental.new-installer false
- Drop patches
  * poetry-1645-1.1.patch
  * poetry-4749-1.1.patch
  * use-new-name-of-MockFixture.patch
- Make multibuild because of circular dependencies with
  python-poetry-plugin-export
* Fri Aug 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.15
  * Poetry now fallback to gather metadata for dependencies via
    pep517 if parsing pyproject.toml fail (#6206)
  * Extras and extras dependencies are now sorted in lock file
    (#6207)
* Fri Jul  8 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.14
  * Fixed an issue where dependencies hashes could not be retrieved
    when locking due to a breaking change on PyPI JSON API (#5973)
* Fri Mar 18 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.13
  * Fixed an issue where envs in MSYS2 always reported as broken
    (#4942)
  * Fixed an issue where conda envs in windows are always reported
    as broken(#5008)
  * Fixed an issue where Poetry doesn't find its own venv on poetry
    self update (#5048)
- Refresh use-new-name-of-MockFixture.patch
- Drop poetry-3544-py310.patch
* Fri Dec 17 2021 Ben Greiner <code@bnavigator.de>
- Add poetry-3544-py310.patch for compatibility with Python 3.10
  gh#python-poetry/poetry#3544
* Sat Dec  4 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.1.12
  * Fixed broken caches on Windows due to Path starting with a
    slash (#4549)
  * Fixed JSONDecodeError when installing packages by updating
    cachecontrol version (#4831)
  * Fixed dropped markers in dependency walk (#4686)
- Release notes for 1.1.11
  * Fixed errors when installing packages on Python 3.10. (#4592)
  * Fixed an issue where the wrong git executable could be used on
    Windows. (python-poetry/poetry-core#213)
  * Fixed an issue where the Python 3.10 classifier was not
    automatically added. (python-poetry/poetry-core#215)
- Refresh poetry-4749-1.1.patch
* Sat Dec  4 2021 lucasiregistraaisiti@protonmail.ch
- Add patch to fix compatibility with packaging >= 21.0:
  * poetry-4749-1.1.patch gh#python-poetry/poetry#4749
* Wed Sep 22 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.1.10
  * Fixed an issue where non-sha256 hashes were not checked.
    (#4529)
- Release 1.1.9
  * Fixed a security issue where file hashes were not checked
    prior to installation. (#4420, #4444, python-poetry/
    poetry-core#193)
  * Fixed the detection of the system environment when the setting
    virtualenvs.create is deactivated. (#4507)
  * Fixed an issue where unsafe parameters could be passed to git
    commands. (python-poetry/poetry-core#203)
  * Fixed an issue where the wrong git executable could be used on
    Windows. (python-poetry/poetry-core#205)
- Release 1.1
  * Fixed an error with repository prioritization when specifying
    secondary repositories. (#4241)
  * Fixed the detection of the system environment when the setting
    virtualenvs.create is deactivated. (#4330, #4407)
  * Fixed the evaluation of relative path dependencies. (#4246)
  * Fixed environment detection for Python 3.10 environments.
    (#4387)
  * Fixed an error in the evaluation of in/not in markers
    (python-poetry/poetry-core#189)
- Release 1.1.7
  * Note: Lock files might need to be regenerated for the first
    fix below to take effect. You can use poetry lock to do so
    without the --no-update option.
  * This release is compatible with the install-poetry.py
    installation script to ease the migration path from 1.1
    releases to 1.2 releases. (#4192)
  * Fixed an issue where transitive dependencies of directory or
    VCS dependencies were not installed or otherwise removed.
    (#4203)
  * Fixed an issue where the combination of the --tree and
  - -no-dev options for the show command was still displaying
    development dependencies. (#3992)
* Wed Jun 16 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch to adapt code to pytest-mock > 3.3.1 where MockFixture
  was renamed to MockerFixture:
  * use-new-name-of-MockFixture.patch
* Wed Apr 14 2021 Ben Greiner <code@bnavigator.de>
- Release 1.1.6
  * Fixed export format for path dependencies. (#3121)
  * Fixed errors caused by environment modification when executing
    some commands. (#3253)
  * Fixed handling of wheel files with single-digit versions.
    (#3338)
  * Fixed an error when handling single-digit Python markers.
    (poetry-core#156)
  * Fixed dependency markers not being properly copied when
    changing the constraint leading to resolution errors.
    (poetry-core#163)
  * Fixed an error where VCS dependencies were always updated.
    (#3947)
  * Fixed an error where the incorrect version of a package was
    locked when using environment markers. (#3945)
- Release 1.1.5
  * Fixed an error in the export command when no lock file existed
    and a verbose flag was passed to the command. (#3310)
  * Fixed an error where the pyproject.toml was not reverted when
    using the add command. (#3622)
  * Fixed errors when using non-HTTPS indices. (#3622)
  * Fixed errors when handling simple indices redirection. (#3622)
  * Fixed errors when trying to handle newer wheels by using the
    latest version of poetry-core and packaging. (#3677)
  * Fixed an error when using some versions of poetry-core due to
    an incorrect import . (#3696)
- Time to drop simplify-toml.patch instead of refresh -- let
  dephell burn in its own &1
* Tue Oct 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.1.4
  * Added installer.parallel boolean flag (defaults to
    true) configuration to enable/disable parallel
    execution of operations when using the new installer.
    (#3088)
  * When using system environments as an unprivileged user,
    user site and bin directories are created if they do
    not already exist. (#3107)
  * Fixed editable installation of poetry projects when
    using system environments. (#3107)
  * Fixed locking of nested extra activations. If you were
    affected by this issue, you will need to regenerate the
    lock file using poetry lock --no-update. (#3229)
  * Fixed prioritisation of non-default custom package
    sources. (#3251)
  * Fixed detection of installed editable packages when
    non-poetry managed .pth file exists. (#3210)
  * Fixed scripts generated by editable builder to use
    valid import statements. (#3214)
  * Fixed recursion error when locked dependencies contain
    cyclic dependencies. (#3237)
  * Fixed propagation of editable flag for VCS
    dependencies. (#3264)
- Refresh poetry-1645-1.1.patch
* Wed Oct 21 2020 Benjamin Greiner <code@bnavigator.de>
- Run tests in virtualenv gh#python-poetry/poetry#1645
- Add poetry-1645-1.1.patch gh#python-poetry/poetry#3255
* Thu Oct 15 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.1.3
  * Python version support deprecation warning is now written to
    stderr. (#3131)
  * Fixed KeyError when PATH is not defined in environment
    variables. (#3159)
  * Fixed error when using config command in a directory with an
    existing pyproject.toml without any Poetry configuration.
    (#3172)
  * Fixed incorrect inspection of package requirements when same
    dependency is specified multiple times with unique markers.
    (#3147)
  * Fixed show command to use already resolved package metadata.
    (#3117)
  * Fixed multiple issues with export command output when using
    requirements.txt format. (#3119)
* Thu Oct  8 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.1.2
  * Dependency installation of editable packages and all
    uninstall operations are now performed serially within
    their corresponding priority groups. (#3099)
  * Improved package metadata inspection of nested poetry
    projects within project path dependencies. (#3105)
  * Fixed export of requirements.txt when project
    dependency contains git dependencies. (#3100)
- Add missing virtualenv and poetry-core runtime requirements
- Install using pip with poetry-core backend
  * drop dephell setup
- Update simplify-toml.patch
  * fix cleo dep in pyproject.toml as poetry checks that during
    runtime
* Mon Oct  5 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.1.1
  * Added --no-update option to lock command. (#3034)
  * Fixed resolution of packages with missing required extras.
    (#3035)
  * Fixed export of requirements.txt dependencies to include
    development dependencies. (#3024)
  * Fixed incorrect selection of unsupported binary distribution
    formats when selecting a package artifact to install. (#3058)
  * Fixed incorrect use of system executable when building package
    distributions via build command. (#3056)
  * Fixed errors in init command when specifying --dependency in
    non-interactive mode when a pyproject.toml file already exists.
    (#3076)
  * Fixed incorrect selection of configured source url when a
    publish repository url configuration with the same name already
    exists. (#3047)
  * Fixed dependency resolution issues when the same package is
    specified in multiple dependency extras. (#3046)
- More changes for rc, beta and alpha releases see CHANGELOG.md
- Update URL and GitHub repo address
- Update requirements according to pyproject.toml
- Update test suite setup and test deselection
  * gh#python-poetry/poetry#1645
* Wed Aug  5 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.0.10
  * The lock files are now versioned to ease transitions for lock
    file format changes, with warnings being displayed on
    incompatibility detection (#2695).
  * The init and new commands will now provide hints on invalid
    given licenses (#1634).
  * Fixed error messages when the authors specified in the
    pyproject.toml file are invalid (#2525).
  * Fixed empty .venv directories being deleted (#2064).
  * Fixed the shell command for tcsh shells (#2583).
  * Fixed errors when installing directory or file dependencies in
    some cases (#2582).
* Wed Jul 29 2020 Benjamin Greiner <code@bnavigator.de>
- allow keyring >= 20.0.1
* Sun Jul 12 2020 John Vandenberg <jayvdb@gmail.com>
- Skip one test that breaks due to clikit 0.6.0+ improving
  error messages
* Sun Jul  5 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.0.9:
  - Fixed:
  - Fixed an issue where packages from custom indices where continuously updated ([#2525](https://github.com/python-poetry/poetry/pull/2525)).
  - Fixed errors in the way Python environment markers were parsed and generated ([#2526](https://github.com/python-poetry/poetry/pull/2526)).
- update to version 1.0.8:
  - Fixed:
  - Fixed a possible error when installing the root package ([#2505](https://github.com/python-poetry/poetry/pull/2505)).
  - Fixed an error where directory and VCS dependencies were not installed ([#2505](https://github.com/python-poetry/poetry/pull/2505)).
- update to version 1.0.7:
  - Fixed:
  - Fixed an error when trying to execute some packages `setup.py` file ([#2349](https://github.com/python-poetry/poetry/pull/2349)).
  - update to version 1.0.6:
  - Changed:
  - The `self update` command has been updated in order to handle future releases of Poetry ([#2429](https://github.com/python-poetry/poetry/pull/2429)).
  - Fixed:
  - Fixed an error were a new line was not written when displaying the virtual environment's path with `env info` ([#2196](https://github.com/python-poetry/poetry/pull/2196)).
  - Fixed a misleading error message when the `packages` property was empty ([#2265](https://github.com/python-poetry/poetry/pull/2265)).
  - Fixed shell detection by using environment variables ([#2147](https://github.com/python-poetry/poetry/pull/2147)).
  - Fixed the removal of VCS dependencies ([#2239](https://github.com/python-poetry/poetry/pull/2239)).
  - Fixed generated wheel ABI tags for Python 3.8 ([#2121](https://github.com/python-poetry/poetry/pull/2121)).
  - Fixed a regression when building stub-only packages ([#2000](https://github.com/python-poetry/poetry/pull/2000)).
  - Fixed errors when parsing PEP-440 constraints with whitespace ([#2347](https://github.com/python-poetry/poetry/pull/2347)).
  - Fixed PEP 508 representation of VCS dependencies ([#2349](https://github.com/python-poetry/poetry/pull/2349)).
  - Fixed errors when source distributions were read-only ([#1140](https://github.com/python-poetry/poetry/pull/1140)).
  - Fixed dependency resolution errors and inconsistencies with directory, file and VCS dependencies ([#2398](https://github.com/python-poetry/poetry/pull/2398)).
  - Fixed custom repositories information not being properly locked ([#2484](https://github.com/python-poetry/poetry/pull/2484)).
- update simplify-toml.patch to also simplify the pytest dependency.
* Mon May 18 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 1.0.5
  - Fixed an error when building distributions if the `git` executable was not found ([#2105](https://github.com/python-poetry/poetry/pull/2105)).
  - Fixed various errors when reading Poetry's TOML files by upgrading [tomlkit](https://github.com/sdispater/tomlkit).
  - Fixed the PyPI URL used when installing packages ([#2099](https://github.com/python-poetry/poetry/pull/2099)).
  - Fixed errors when the author's name contains special characters ([#2006](https://github.com/python-poetry/poetry/pull/2006)).
  - Fixed VCS excluded files detection when building wheels ([#1947](https://github.com/python-poetry/poetry/pull/1947)).
  - Fixed packages detection when building sdists ([#1626](https://github.com/python-poetry/poetry/pull/1626)).
  - Fixed the local `.venv` virtual environment not being displayed in `env list` ([#1762](https://github.com/python-poetry/poetry/pull/1762)).
  - Fixed incompatibilities with the most recent versions of `virtualenv` ([#2096](https://github.com/python-poetry/poetry/pull/2096)).
  - Fixed Poetry's own vendor dependencies being retrieved when updating dependencies ([#1981](https://github.com/python-poetry/poetry/pull/1981)).
  - Fixed encoding of credentials in URLs ([#1911](https://github.com/python-poetry/poetry/pull/1911)).
  - Fixed url constraints not being accepted in multi-constraints dependencies ([#2035](https://github.com/python-poetry/poetry/pull/2035)).
  - Fixed an error where credentials specified via environment variables were not retrieved ([#2061](https://github.com/python-poetry/poetry/pull/2061)).
  - Fixed an error where git dependencies referencing tags were not locked to the corresponding commit ([#1948](https://github.com/python-poetry/poetry/pull/1948)).
  - Fixed an error when parsing packages `setup.py` files ([#2041](https://github.com/python-poetry/poetry/pull/2041)).
  - Fixed an error when parsing some git URLs ([#2018](https://github.com/python-poetry/poetry/pull/2018)).
* Mon Mar 23 2020 Matej Cepl <mcepl@suse.com>
- Add macro %%dephell_genspec to generate setup.py
* Sun Feb 16 2020 Tomas Heger <heger.tomas@gmail.com>
- Update to v1.0.3
  * Changes in 1.0.3
  - Fixed an error which caused the configuration environment
    variables
  - Fixed an error where the `--help` option was not working
  - Fixed an error where packages from private indices were not
    decompressed properly
  - Fixed an error where the version of some PEP-508-formatted
    wheel dependencies was not properly retrieved
  - Fixed internal regexps to avoid potential catastrophic
    backtracking errors
  - Fixed performance issues when custom indices were defined in
    the `pyproject.toml` file
  - Fixed the `get_requires_for_build_wheel
  * Changes in 1.0.2
  - Reverted a previous fix
  * Changes in 1.0.1
  - Fixed an error in `env use` where the wrong Python executable
    was being used to check compatibility
  - Fixed an error where VCS dependencies were not properly
    categorized as development dependencies
  - Fixed an error where some shells would no longer be usable
    after using the `shell` command
  - Fixed an error where explicitly included files where not
    included in wheel distributions
  - Fixed an error where some Git dependencies url were not
    properly parsed
  - Fixed an error in the `env` commands on Windows if the path
    to the executable contained a space
  - Fixed several errors and UX issues caused by `keyring` on
    some systems
  - Fixed errors when trying to detect installed packages
  - Fixed an error when packaging projects where Python packages
    were not properly detected
  - Fixed an error where local file dependencies were exported as
    editable when using the `export` command
  - Fixed the way environment markers are propagated and
    evaluated when resolving dependencies
  - Fixed an error in the PEP-508 compliant representation of
    directory and file dependencies
  - Fixed an error where invalid virtual environments would be
    silently used. They will not be recreated and a warning will
    be displayed
  - Fixed an error where dependencies were not properly detected
    when reading the `setup.py` file in some cases
- refresh simplify-toml.patch
- update to version 1.0.1 also fixes bsc#1163765
* Wed Dec 18 2019 John Vandenberg <jayvdb@gmail.com>
- Remove dephell build workaround
* Tue Dec 17 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0.0
* Tue Sep 17 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0.0b1
* Sat May 18 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.12.16
